<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;

class ClientsController extends Controller
{
    public function __construct()
    {
        $this->middleware(['permission:clients,admin']);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = User::where('type', 'client')->orderByDesc('id')->paginate(10);
        $active_rows = User::where(['type' => 'client', 'status' => 'active'])->orderByDesc('id')->paginate(10);
        $not_active_rows = User::where(['type' => 'client', 'status' => 'not_active'])->orderByDesc('id')->paginate(10);
        return view('admin.client.index', compact('rows', 'not_active_rows', 'active_rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

    public function client_search(Request $request)
    {
        $this->validate($request, [
            'search' => 'required'
        ]);
        $req = $request->search;
        $search = is_numeric($request->search);
        if ($search == 1) {
            $rows = User::where('type', 'client')->where('mobile', 'LIKE', "%$request->search%")->paginate(10);
        } else {
            $rows = User::where('type', 'client')->where('name', 'LIKE', "%$request->search%")->paginate(10);
        }
        return view('admin.client.search', compact('rows', 'req'));
    }

    public function delete_clients_ajax()
    {
        $ids = explode(",", request()->ids);
        foreach ($ids as $id) {
            $user = User::find($id);
            $user->delete();
        }
        return response()->json(['data' => 'done']);
    }

    public function block_clients_ajax()
    {
        $ids = explode(",", request()->ids);
        foreach ($ids as $id) {
            $user = User::find($id);
            $user->status = 'block';
            $user->update();
        }
        return response()->json(['data' => 'done']);
    }

    public function not_active_clients_ajax()
    {
        $ids = explode(",", request()->ids);
        foreach ($ids as $id) {
            $user = User::find($id);
            $user->status = 'not_active';
            $user->update();
        }
        return response()->json(['data' => 'done']);
    }

    public function active_clients_ajax()
    {
        $ids = explode(",", request()->ids);
        foreach ($ids as $id) {
            $user = User::find($id);
            $user->status = 'active';
            $user->update();
        }
        return response()->json(['data' => 'done']);
    }

    public function update_password($id)
    {
        $row = User::find($id);
        return view('admin.client.user_password', compact('row'));
    }

    public function update_password_form($id, Request $request)
    {
        $this->validate($request, [
            'password' => 'required|min:6|confirmed'
        ]);
        $user = User::find($id);
        $user->password = bcrypt($request->password);
        $user->first_login = 'true';
        $user->update();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('clients.index');
    }
}
