<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\OrderMessages;
use Illuminate\Http\Request;

class OrderMessagesController extends Controller
{
    public function __construct()
    {
        $this->middleware(['permission:order_messages,admin']);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index($country_id)
    {


        $rows = OrderMessages::whereCountryId($country_id)->get();
        return view('admin.order_messages.index', compact('rows', 'country_id'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create($country_id)
    {
        $status = [
            'new' => 'جديد',
            'paid' => 'مدفوع',
            'foreign_accept' => 'موافقة المكتب الاجنبى',
//        'not_verified' => 'غير موثق',
            'polo' => 'فى البولو',
            'verified' => 'موثق',
            'in_shipping' => 'فى الشحن - إرسال العقود',
            'in_progress' => 'تحت الاجراء',
            'travel' => 'السفر',
            'delivered' => 'تم التوصيل',
            'cancel' => 'ملغي',
        ];
        return view('admin.order_messages.create', compact('status', 'country_id'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        $this->validate($request, [
            'message' => 'required',
            'country_id' => 'required',
            'type' => 'required',
            'status' => 'required|in:active,not_active',
        ]);

        $old_message = OrderMessages::where(['country_id' => request()->country_id, 'type' => $request->type])->first();

        if (isset($old_message)) {
            alert('خطأ', 'تم الاضافه من قبل برجاء التعديل هنا', 'error');
            return route('order_messages_edit', $old_message->id);
        }

        $message = new OrderMessages();
        $message['message'] = request()->message;
        $message['country_id'] = request()->country_id;
        $message['type'] = $request->type;
        $message['status'] = $request->status;
        $message->save();
        success_toast();
        return redirect()->route('countryOrderMessageIndex', $request['country_id']);


    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $status = [
            'new' => 'جديد',
            'paid' => 'مدفوع',
            'foreign_accept' => 'موافقة المكتب الاجنبى',
//        'not_verified' => 'غير موثق',
            'polo' => 'فى البولو',
            'verified' => 'موثق',
            'in_shipping' => 'فى الشحن - إرسال العقود',
            'in_progress' => 'تحت الاجراء',
            'travel' => 'السفر',
            'delivered' => 'تم التوصيل',
            'cancel' => 'ملغي',
        ];
        $row = OrderMessages::findOrFail($id);
        return view('admin.order_messages.edit', compact('row', 'status'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {

        $this->validate($request, [
            'message' => 'required',
            'status' => 'required|in:active,not_active',
        ]);


        $message = OrderMessages::find($id);
        $message['message'] = request()->message;
        $message['status'] = $request->status;
        $message->update();

        success_toast();
        return redirect()->route('countryOrderMessageIndex', $message->country_id);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        OrderMessages::destroy($id);
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->back();
    }
}
