<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Partner;
use App\Repositories\Client\PartnersRepository;
use Illuminate\Http\Request;

class PartnersController extends Controller
{
    /**
     * @var PartnersRepository
     */
    private $partnersRepository;

    public function __construct(PartnersRepository $partnersRepository)
    {
        $this->partnersRepository = $partnersRepository;
        $this->middleware(['permission:partners,admin']);
    }

    public function index()
    {
        $rows = $this->partnersRepository->index();
        return view('admin.partners.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.partners.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'image' => 'required|image'
        ]);
        return $this->partnersRepository->store();
    }

    public function edit($id)
    {
        $row = Partner::findOrFail($id);
        return view('admin.partners.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'image' => 'image'
        ]);
        return $this->partnersRepository->update($id);
    }

    public function destroy($id)
    {
        return $this->partnersRepository->destroy($id);
    }
}
