<?php

namespace App\Http\Controllers\Foreign;

use App\Http\Controllers\Controller;
use App\Repositories\Foreign\ComplaintsRepository;
use App\Repositories\Foreign\OrdersRepository;
use Illuminate\Http\Request;

class ComplaintsController extends Controller
{
    private $complaintsRepository;
    /**
     * @var OrdersRepository
     */
    private $ordersRepository;
    /**
     * @var \App\Repositories\Client\OrdersRepository
     */
    private $clientOrderRepository;

    public function __construct(ComplaintsRepository $complaintsRepository, OrdersRepository $ordersRepository, \App\Repositories\Client\OrdersRepository $clientOrderRepository)
    {
        $this->complaintsRepository = $complaintsRepository;
        $this->ordersRepository = $ordersRepository;
        $this->clientOrderRepository = $clientOrderRepository;
    }

    public function index()
    {
        $rows = $this->complaintsRepository->index();
        $orders = $this->ordersRepository->index();
        return view('site.foreign.complaints', compact('rows', 'orders'));
    }

    public function worker_name_ajax_foreign(Request $request)
    {
        $worker_name = $this->clientOrderRepository->worker_name($request->order_id);


        $worker_name = view('site.client.worker_name',compact('worker_name'))->render();
        return response()->json(['value'=>true,'worker_name'=>$worker_name]);
    }


    public function store(Request $request)
    {
        $this->validate($request,[
            'order_id'=>'required',
            'notes'=>'required',
        ]);
        $this->complaintsRepository->store();
        success_toast();
        return redirect()->back();
    }

    public function update($id, Request $request)
    {

        $this->validate($request,[
            'status'=>'required|in:new,closed,contacted'
        ]);
        $this->complaintsRepository->update($id);
        success_toast();
        return redirect()->back();
    }
    public function  reply_complaint($complaint_id,Request  $request){

        $this->validate($request,[
            'reply'=>'required'
        ]);
        $this->complaintsRepository->replyComplaint($complaint_id);

        success_toast();
        return redirect()->back();
    }
    public function compliant_search_ajax(Request  $request){

        $rows = $this->complaintsRepository->complaintCode($request['compliant_code']);

        $compliantSearch = view('site.saudi.complaintSearch',compact('rows'))->render();

        return response()->json(['value'=>true,'compliantSearch'=>$compliantSearch]);

    }

}
