<?php

namespace App\Http\Controllers\Workers;

use App\Http\Controllers\Controller;
use App\Models\Order;
use App\Repositories\Client\UsersRepository;
use App\Repositories\Worker\CountriesRepository;
use App\Repositories\Worker\GivenNameOrderRepository;
use App\Repositories\Worker\JobTitlesRepository;
use Illuminate\Http\Request;

class GivenNameOrdersController extends Controller
{


    private $usersRepository;
    /**
     * @var JobTitlesRepository
     */
    private $jobTitlesRepository;
    /**
     * @var CountriesRepository
     */
    private $countriesRepository;
    /**
     * @var GivenNameOrderRepository
     */
    private $givenNameOrderRepository;

    public function __construct(UsersRepository $usersRepository, JobTitlesRepository $jobTitlesRepository, CountriesRepository $countriesRepository, GivenNameOrderRepository $givenNameOrderRepository)
    {
        $this->usersRepository = $usersRepository;
        $this->jobTitlesRepository = $jobTitlesRepository;
        $this->countriesRepository = $countriesRepository;
        $this->givenNameOrderRepository = $givenNameOrderRepository;
    }

    public function given_name_order()
    {
        if (request()->type == 'given_name' || request()->type == 'given_service') {
            session()->put('type', request()->type);
            return view('site.saudi.givenNameOrder.index');
        }
        return redirect()->back();
    }

    public function first_name_order(Request $request)
    {

        $client = $this->usersRepository->checkUserExist();

        if ($client && $client->mobile != $request['client_mobile']) {
            $validation = 'required|unique:users,email|email';
        } elseif ($client) {
            $validation = 'required|email';
        } else {
            $validation = 'required|email';

        }

        $this->validate($request, [
            'client_name' => 'required',
            'client_mobile' => 'required',
            'civil_registry' => 'required',
            'id_number' => 'required',
            'city' => 'required',
            'area' => 'required',
            'family_count' => 'required',
            'social_status' => 'required',
            'client_email' => $validation,
            'client_residency_number' => 'required',
        ]);

        $client = $this->usersRepository->createNewAccount();

        session()->put('client_mobile', $client->mobile);
        session()->put('client', $client);
        return redirect()->route('second_name_order');
    }

    public function second_name_order()
    {
        $job_titles = $this->jobTitlesRepository->index();
        return view('site.saudi.givenNameOrder.second_name_order', compact('job_titles'));
    }

    public function second_name_order_submit(Request $request)
    {


        $this->validate($request, [
            'name' => 'required',
            'id_number' => 'required',
            'mobile' => 'required',
            'email' => 'required|email',
            'social_status' => 'required',
            'civil_registry' => 'required',
            'address' => 'required',
            'passport_number' => 'required',
            'passport_start' => 'required',
            'visa_number' => 'required',
            'gender' => 'required|in:male,female',
            'passport_end' => 'required',
            'passport_attachment' => 'required|image',
            'job_title_id' => 'required|exists:job_titles,id'
        ]);


        if ($request->hasFile('passport_attachment')) {
            $filename = time() . '.' . $request->passport_attachment->getClientOriginalExtension();
            $request->passport_attachment->move(public_path('images/orders'), $filename);
            $request['passport_image'] = $filename;
        }
        session()->put('given_name_details', $request->except(['_token', 'passport_attachment']));

        return redirect()->route('third_given_name');

    }

    public function third_given_name()
    {
        $countries = $this->countriesRepository->index();
        return view('site.saudi.givenNameOrder.third_name_order', compact('countries'));
    }

    public function getOfficesByCountry(Request $request)
    {
        $rows = $this->usersRepository->Offices($request['country_id']);
        $officesResult = view('site.saudi.givenNameOrder.offices', compact('rows'))->render();
        return response()->json(['value' => true, 'officesResult' => $officesResult]);
    }

    public function third_name_order_submit(Request $request)
    {
        $this->validate($request, [
            'office_id' => 'required|exists:users,id'
        ]);


        $order_details = session()->get('given_name_details');
        $order_details['office_id'] = $request['office_id'];
        session()->put('given_name_details', $order_details);
        return redirect()->route('fourth_given_name_order');
    }

    public function fourth_given_name_order()
    {
        $order_details = session()->get('given_name_details');
        $worker_name = $order_details['name'];
        $office_name = $this->usersRepository->office_name($order_details['office_id']);

        return view('site.saudi.givenNameOrder.fourth_name_order', compact('worker_name', 'office_name'));
    }

    public function fourth_given_name_submit(Request $request)
    {
        $this->validate($request, [
            'passport_image' => 'required|image',
            'family_card' => 'required|image'
        ]);


        $order_details = session()->get('given_name_details');
        if ($request->hasFile('passport_image')) {
            $filename = 'passport_image' . time() . '.' . $request['passport_image']->getClientOriginalExtension();
            $request['passport_image']->move(public_path('images/orders'), $filename);
            $order_details['passport_image'] = $filename;
        }


        if ($request->hasFile('family_card')) {
            $filename = 'family_card' . time() . '.' . $request['family_card']->getClientOriginalExtension();
            $request['family_card']->move(public_path('images/orders'), $filename);
            $order_details['family_card'] = $filename;
        }
        session()->put('given_name_details', $order_details);


        return redirect()->route('fifth_given_name_order');

    }

    public function fifth_given_name_order()
    {
        return view('site.saudi.givenNameOrder.fifth_name_order');
    }

    public function fifth_given_name_submit(Request $request)
    {
        $this->validate($request, [
            'follow_type' => 'required|in:sms,email,both',
            'client_sign' => 'required|image'
        ]);


        return $this->givenNameOrderRepository->store();

    }

    public function last_given_name_order($order_id)
    {
        $order = Order::findOrFail($order_id);
        return view('site.saudi.givenNameOrder.last_given_name_order', compact('order'));
    }
}
