<?php

namespace App\Repositories\Foreign;

use App\Models\Cv;
use App\Models\CvExperince;
use App\Models\CvSkill;

class ResumesRepository
{
    public function index()
    {
        return Cv::whereOfficeId(auth()->id())->paginate(10);
    }

    public function store($request)
    {
        $request['office_id'] = auth()->id();
        $cv = Cv::create($request->except('skills', 'country', 'period', 'date'));
        if ($request['skills'] && count($request['skills']) > 0) {
            foreach ($request['skills'] as $skill) {
                CvSkill::create([
                    'skill_id' => $skill,
                    'cv_id' => $cv->id
                ]);
            }
        }
        $country_count = count($request['country']);
        for ($i = 0; $i < $country_count; $i++) {

            $experience = new CvExperince();
            $experience->cv_id = $cv->id;
            $experience->country = $request['country'][$i];
            $experience->period = $request['period'][$i];
            $experience->date = $request['date'][$i];

            $experience->save();
        }
        success_toast();
        return redirect()->route('resumes.index');
    }

    public function destroy($id)
    {
        Cv::destroy($id);
        success_toast();
        return redirect()->back();
    }

    public function show($id)
    {
        return Cv::findOrFail($id);
    }

    public function update($id, $request)
    {
        Cv::whereId($id)->update($request->except('skills', 'country', 'period', 'date', 'office_id','_token','_method'));
        if ($request['skills'] && count($request['skills']) > 0) {
            CvSkill::whereCvId($id)->delete();
            foreach ($request['skills'] as $skill) {
                CvSkill::create([
                    'skill_id' => $skill,
                    'cv_id' => $id
                ]);
            }
        }
        $country_count = count($request['country']);
        if ($country_count > 0) {
            CvExperince::whereCvId($id)->delete();
        }
        for ($i = 0; $i < $country_count; $i++) {

            $experience = new CvExperince();
            $experience->cv_id = $id;
            $experience->country = $request['country'][$i];
            $experience->period = $request['period'][$i];
            $experience->date = $request['date'][$i];

            $experience->save();
        }
        success_toast();
        return redirect()->route('resumes.index');
    }
}
